<?php

    class Load_Metadata_To_Context_Action extends Reactor_Action
    {
        protected $tpl = 'load_metadata_to_context.php';
        protected $name = 'Load metadata to a context variable';
		
		public static $registration = array(
			ACTION_NAME => 'Load metadata to context',
			ACTION_CATEGORY => 'Nagios Reactor',
			ACTION_DESCRIPTION => 'Reads a persisted metadata value and copies it to a context variable.',
			ACTION_AUTHOR => 'Jeremy Yunis, Nagios Enterprises, LLC',
			ACTION_VERSION => '1.0',
			ACTION_DATE => '02/18/2013', //Last version update
			ACTION_AUTHLEVEL => 0,  // 0 - everyone | 1 - Admin only
			ACTION_TYPE => 'core', //core | user. core modules can't be deleted
			ACTION_META => array(),	//Misc information	
		); 
		
        protected $fields = array(
            'metadata_key' => array(
                'label' => 'metadata key',
                'validate' => 'trim|required|alpha_dash|xss_clean|prep_for_form',
            ),
            'context_varname' => array(
                'label' => 'context variable',
                'validate' => 'trim|required|alpha_dash|xss_clean|prep_for_form',
            ),
        );

        public function get_label()
        {
            if($params = $this->get_params()) {
                if(array_key_exists('metadata_key', $params) &&
                        array_key_exists('context_varname', $params)) {
                    return sprintf('Load metadata key \'%s\' to context variable \'%s\'', $params['metadata_key'], $params['context_varname']);
                }
            }
            return parent::get_label();
        }
       
        public function run($context)
        {
            $this->set_context($context);
            $params = $this->get_params();
            if(array_key_exists('metadata_key', $params) &&
                array_key_exists('context_varname', $params)) {
                    if($meta_row = $this->ci->metadata_model->get_by_key($params['metadata_key'])) {
                        $context[$params['context_varname']] = $meta_row->value;
                    }
            }
            $this->set_result(0); 
            return $context;
        }
    }
